# Spell Checker ML

The goal of this library is to provide a spell checker trained on a language model.  The interface is the same as pyspellchecker, however the language model adds context to the spell checker, for an improved likely correct spelling.

